@@ -30,20 +30,17 @@ import sys
 import time
 
 # cli specific imports
-from .ui_utils import menu_options, app_header, format_msg
-from .utils import (get_correct_answer, ask_yes_no, path_fixer,
-                    SetupConfig, _directory_fixer, install_client_package,
-                    write_client_config, FROZEN)
+from cli.ui_utils import menu_options, app_header, format_msg
+from cli.utils import (get_correct_answer, path_fixer, SetupConfig,
+                       _directory_fixer, install_client_package,
+                       write_client_config)
 
 # framework stuff
-from not_so_tuf import NotSoTuf
-from not_so_tuf.client import Client
+from not_so_tuf import (NotSoTuf, Client, FileCrypt, KeyHandler,
+                        PackageHandler, Uploader)
+
 from not_so_tuf.compat import input_, print_function
-from not_so_tuf.filecrypt import FileCrypt
-from not_so_tuf.key_handler import KeyHandler
-from not_so_tuf.package_handler import PackageHandler
-from not_so_tuf.uploader import Uploader
-from not_so_tuf.utils import _cwd
+from not_so_tuf.utils import _cwd, FROZEN, ask_yes_no
 from not_so_tuf.version import __version__
 
 
@@ -53,6 +50,11 @@ h = logging.NullHandler()
 h.setLevel(logging.DEBUG)
 log.addHandler(h)
 
+c = logging.StreamHandler()
+c.addFilter(logging.Filter('not_so_tuf.client'))
+c.setLevel(logging.INFO)
+log.addHandler(c)
+
 
 class Ui(object):
 
@@ -199,7 +201,7 @@ class Ui(object):
                    ('Update Settings', self.update_settings),
                    ('Decrypt and Copy Config', self.copy_decrypted_config),
                    ('Initial Setup', self.initial_setup),
-                   ('Delete Password', self.delete_password),
+                   ('Delete Folder Password', self.delete_password),
                    ('Go Back', self.main)]
 
         next = menu_options(options)
@@ -214,17 +216,38 @@ class Ui(object):
         print(format_msg(msg))
         answer = ask_yes_no('Are you sure you want to continue?\nSelecting no '
                             'will return you to the main menu!', default='no')
-        if not answer:
+        if answer is False:
             self.main()
 
         answer = ask_yes_no('Would you like to make decrypted copies of '
-                            'both files now?  If you choose no there is '
-                            'not going back.  You have been warned.',
+                            'both files now?\nIf you choose no there is '
+                            'no going back.  You have been warned.',
                             default='y')
         if answer:
-            self.copy_decrypted_config()
-            self.private_key_copy()
-        self.delete_password()
+            print(format_msg('You will be asked for you password multiple'
+                  ' times to decrypt your files and one last time to confirm'
+                  ' folder password deletion'))
+
+            log.debug('Attempting to copy decrypted config')
+            filename = os.path.join(_cwd, 'config.data')
+            fc = FileCrypt(filename)
+            fc.decrypt()
+            try:
+                shutil.copy(filename, filename + ' copy')
+                log.debug('Copied config')
+            except Exception as e:
+                log.error(str(e), exc_info=True)
+                log.error('Cannot copy decrypted config file')
+            fc.encrypt()
+            msg = ('Decrypted config file & private key copied.'
+                   'Press enter to continue')
+            log.debug('Copied private key')
+            key_handler = KeyHandler(self.nst)
+            key_handler.copy_decrypted_private_key()
+            raw_input(format_msg(msg))
+        fc = FileCrypt()
+        fc.del_folder_password()
+        print('Folder password deleted')
 
     def view_settings(self):
         log.debug('View Settings Menu')
@@ -327,12 +350,12 @@ class Ui(object):
         priv_key_name = get_correct_answer('Enter a name to give '
                                            'your private key',
                                            default='Not-So-TUF')
-        self.config.add_private_key_name(priv_key_name)
+        self.config.PRIVATE_KEY_NAME = priv_key_name
 
         pub_key_name = get_correct_answer('Enter a name to give your'
                                           ' public key',
                                           default='Not-So-TUF')
-        self.config.add_public_key_name(pub_key_name)
+        self.config.PUBLIC_KEY_NAME = pub_key_name
 
         self.config.UPDATE_URL = get_correct_answer('Enter your update url',
                                                     required=True)
@@ -373,7 +396,7 @@ class Ui(object):
                                                                'Access Key',
                                                                required=True)
             self.config.BUCKET_NAME = get_correct_answer('Enter bucket name',
-                                                         reuqired=True)
+                                                         required=True)
 
         if answer3:
             self.config.FTP_USERNAME = get_correct_answer('Enter ftp username',
@@ -434,7 +457,7 @@ class Ui(object):
 class ClientConfig(object):
 
     UPDATE_URL = 'https://s3-us-west-1.amazonaws.com/not-so-tuf/'
-    PUBLIC_KEY = (16464922665638673681992463013273935612664219094906980149897613483558764958275503471833999796774944451919679352299199781040261183626243789235159282484489660866211751942888040512642103075255732190154437871072326800313353343988071645793491504044388864374910418983325794095950121251375913490389709129928619827303368362856224581261135920008510653620012541583622789200202174035822993035846677533547389325544764270670429010858826140320098873827212627840823767544126373206301938873536107735052145489782939917808169280407467079055393335221958452100971113008041835393071679231080475062804424979544387709688694450412240360063013, 65537)
+    PUBLIC_KEY = (20637918838630146524012555291263525420338623201753105666623728757477474356657906830808661219028216989037203292726284423707012615957813371837082638820856919286542588915494816902242062141756384083808146819599797016833870748088257100050904974059248742661177769813373280841426857743509287209467071907257767361007079268648281060851890195285885561482110828126385187454827976579811917126680368227368761076536237058918226099098632661456329296561356753284005782554399908660562765138439107357312499232680987929449258473407746762247921953401044842400143205607346895238132577984154582616033223797394204680884015618921132529024369L, 65537)
 
 
 def main():
