@@ -28,7 +28,7 @@ import struct
 import subprocess
 import sys
 
-from not_so_tuf.compat import print_function
+from not_so_tuf.compat import print_function, xrange_
 from not_so_tuf.version import __version__
 
 log = logging.getLogger(__name__)
@@ -159,7 +159,7 @@ def menu_options(*args):
             count += 1
         print(''.join(menu))
         answers = []
-        for a in xrange(1, len(menu) + 1):
+        for a in xrange_(1, len(menu) + 1):
             answers.append(str(a))
         while 1:
             ans = getch()
@@ -188,7 +188,7 @@ def get_terminal_size():
     if current_os in ['Linux', 'Darwin'] or current_os.startswith('CYGWIN'):
         tuple_xy = _get_terminal_size_linux()
     if tuple_xy is None:
-        print_function("default")
+        print("default")
         tuple_xy = (80, 25)      # default value
     return tuple_xy
 
