@@ -21,22 +21,18 @@
 # SOFTWARE.
 
 
-import hashlib
 import logging
 import os
 import shutil
 import sys
-import urllib2
 
-from not_so_tuf.compat import print_function
-from not_so_tuf.utils import _cwd
+from not_so_tuf.compat import print_function, urllib2
+from not_so_tuf.utils import _cwd, FROZEN, ChDir, ask_yes_no
 from not_so_tuf.version import __version__
 
 
 log = logging.getLogger(__name__)
 
-FROZEN = getattr(sys, 'frozen', False)
-
 
 class SetupConfig(object):
     # If left None "Not_So_TUF" will be used
@@ -99,14 +95,9 @@ class SetupConfig(object):
     SECRET_ACCESS_KEY = None
     BUCKET_NAME = None
 
-    def add_private_key_name(self, name):
-        self.PRIVATE_KEY_NAME = name + '.pem'
 
-    def add_public_key_name(self, name):
-        self.PUBLIC_KEY_NAME = name + '.pub'
-
-
-def get_correct_answer(question, default=None, required=False):
+def get_correct_answer(question, default=None, required=False,
+                       answer=None, is_answer_correct=None):
     while 1:
         if default is None:
             msg = 'None'
@@ -114,42 +105,22 @@ def get_correct_answer(question, default=None, required=False):
             msg = ('\n[DEFAULT] -> {}\nPress Enter To '
                    'Use Default'.format(default))
         prompt = question + msg + '\n--> '
-        answer = raw_input(prompt)
+        if answer is None:
+            answer = raw_input(prompt)
         if answer == '' and required:
-            print_function('You have to enter a value\n\n')
+            print('You have to enter a value\n\n')
             raw_input('Press enter to continue')
-            print_function('\n\n')
+            print('\n\n')
             continue
         if answer == '' and default is not None:
             answer = default
-        _ans = ask_yes_no('You entered {}, is this correct?'.format(answer))
+        _ans = ask_yes_no('You entered {}, is this '
+                          'correct?'.format(answer),
+                          answer=is_answer_correct)
         if _ans:
             return answer
-
-
-def ask_yes_no(question, default='no'):
-    default = default.lower()
-    yes = ['yes', 'ye', 'y']
-    no = ['no', 'n']
-    if default in no:
-        help = '[N/y]?'
-        default = False
-    else:
-        default = True
-        help = '[Y/n]?'
-    while 1:
-        display = question + '\n' + help
-        answer = raw_input(display)
-        if answer == '':
-            return default
-        if answer in yes:
-            return True
-        elif answer in no:
-            return False
         else:
-            print_function('Please answer yes or no only!\n')
-            raw_input('Press enter to continue')
-            print_function('\n\n\n\n')
+            answer = None
 
 
 # Fixed path to work without quotes
@@ -159,33 +130,11 @@ def path_fixer(path):
     path.replace("'", "")
     path.replace('"', '')
 
-    # Correcting the path with spaces to work
-    # without quotes
+    # Correcting the path to work without
+    # quotes
     return path.replace(' ', '\ ')
 
 
-# Explains itself
-def sha_digest(data):
-    return hashlib.sha256(data).hexdigest()
-
-
-class ChDir(object):
-    """Step into a directory temporarily. Then return to orignal
-    directory.
-    """
-    def __init__(self, path):
-        self.old_dir = os.getcwd()
-        self.new_dir = path
-
-    def __enter__(self):
-        log.debug('Changing to Directory --> {}'.format(self.new_dir))
-        os.chdir(self.new_dir)
-
-    def __exit__(self, *args):
-        log.debug('Moving back to Directory --> {}'.format(self.old_dir))
-        os.chdir(self.old_dir)
-
-
 # Makes inputting directory more like shell
 def _directory_fixer(_dir):
     if _dir == 'Current Working Directory':
@@ -198,27 +147,45 @@ def _directory_fixer(_dir):
     return _dir
 
 
-def install_client_package():
+def install_client_package(test=False):
     files = ['__init__.py', 'downloader.py', 'client.py',
              'utils.py', 'patcher.py', 'version.py']
     package_name = 'not_so_tuf'
-    dir_ = os.path.abspath(sys._MEIPASS)
-    url = ('https://raw.github.com/JohnyMoSwag/Not-So-'
-           'TUF/master/not_so_tuf/version.py')
-    version_file = urllib2.urlopen(url).read()
+    if test:
+        dir_ = os.getcwd()
+        version_file = 0
+    else:
+        dir_ = os.path.abspath(sys._MEIPASS)
+        url = ('https://raw.github.com/JohnyMoSwag/Not-So-'
+               'TUF/master/not_so_tuf/version.py')
+        version_file = urllib2.urlopen(url).read()
 
     if __version__ != version_file:
-        with ChDir(_cwd):
-            if os.path.exists(package_name):
-                shutil.rmtree(package_name, ignore_errors=True)
-            os.mkdir(package_name)
-            for f in files:
-                shutil.copy(os.path.join(dir_, f), package_name)
+        if test:
+            package_dir = os.path.abspath(os.path.join('tests/not_so_tuf'))
+            with ChDir('tests'):
+                if os.path.exists(package_name):
+                    shutil.rmtree(package_name)
+                os.mkdir(package_name)
+            with ChDir('not_so_tuf'):
+                for f in files:
+                    shutil.copy(f, package_dir)
+
+        else:
+            with ChDir(_cwd):
+                if os.path.exists(package_name):
+                    shutil.rmtree(package_name, ignore_errors=True)
+                os.mkdir(package_name)
+                for f in files:
+                    shutil.copy(os.path.join(dir_, f), package_name)
 
 
-def write_client_config(config_object):
-    if FROZEN:
-        package_dir = os.path.join(_cwd, 'not_so_tuf')
+def write_client_config(config_object, test=False):
+    if FROZEN or test is True:
+        if test:
+            package_dir = 'tests/not_so_tuf'
+        else:
+            package_dir = os.path.join(_cwd, 'not_so_tuf')
         if getattr(config_object, 'UPDATE_URL', False):
             update_url = config_object.UPDATE_URL
         else:
