@@ -26,18 +26,15 @@ import os
 import re
 import shutil
 import sys
-import urllib2
 from zipfile import ZipFile
 
-from .downloader import FileDownloader
-from .patcher import Patcher
-from .utils import (ChDir, rsa_verify, _version_string_to_tuple,
-                    _version_tuple_to_string, platform_)
+from not_so_tuf.compat import urllib2, execute_permission
+from not_so_tuf.downloader import FileDownloader
+from not_so_tuf.patcher import Patcher
+from not_so_tuf.utils import (ChDir, rsa_verify, _version_string_to_tuple,
+                              _version_tuple_to_string, platform_)
 
 log = logging.getLogger(__name__)
-c = logging.StreamHandler()
-c.setLevel(logging.INFO)
-log.addHandler(c)
 
 
 class Client(object):
@@ -170,7 +167,7 @@ class Client(object):
         updated_app = os.path.join(self.update_folder, self.fixed_filename)
         if sys.platform != 'win32':
             shutil.move(updated_app, current_app)
-            os.chmod(current_app, 0755)
+            os.chmod(current_app, execute_permission)
             log.info('Restarting')
             os.execv(current_app, [current_app])
         else:
