@@ -25,8 +25,8 @@ from io import BytesIO
 import logging
 import time
 import sys
-import urllib2
 
+from not_so_tuf.compat import urllib2, print_function
 
 log = logging.getLogger(__name__)
 c = logging.StreamHandler()
@@ -142,7 +142,7 @@ class FileDownloader(object):
             recieved_data += len(file_data)
             end_block = time.time()
             if not file_data:
-                print '\n'
+                print('\n')
                 self.my_file.flush()
                 self.my_file.seek(0)
                 self.file_binary_data = self.my_file.read()
