@@ -26,11 +26,12 @@ import logging
 import os
 import sys
 
-from not_so_tuf import NotSoTufError
+from not_so_tuf.exceptions import NotSoTufError
+from not_so_tuf import beefish
+from not_so_tuf.compat import is_py2
 from not_so_tuf.utils import _cwd
 
 try:
-    import beefish
     import keyring
     import pbkdf2
 except ImportError:
@@ -49,13 +50,16 @@ class FileCrypt(object):
         filename (str): The name of the file to encrypt
     """
 
-    def __init__(self, filename=None):
+    def __init__(self, filename=None, test=False):
+        if filename is None:
+            filename = 'Must be deleting folder password'
         self.filename = filename
         self.enc_filename = filename + '.enc'
         self.filenames = None
         self.password = None
         self.tries = 0
-        self._get_password()
+        if not test:
+            self._get_password()
 
     def encrypt(self):
         """Encrypts file and deletes original"""
@@ -81,6 +85,16 @@ class FileCrypt(object):
         except IOError:
             log.warning('Cannot find encrypted file.')
 
+    def del_folder_password(self):
+        username, app_name = self.make_username_appname()
+        self._get_password()
+        if self.password:
+            log.info('About to delete keyring password')
+            keyring.delete_password(app_name, username)
+            del self.password
+        else:
+            pass
+
     def _del_internal_password(self):
         """Deletes user password once its not needed.
         i.e. when the file been encrypted.
@@ -90,7 +104,7 @@ class FileCrypt(object):
 
     def _get_password(self):
         """Gets user passwod without echoing to console"""
-        username = self.make_username()
+        username, app_name = self.make_username_appname()
         app_name = 'NST-' + username
         log.info('Looking for keyring password')
         keyring_password = keyring.get_password(app_name, username)
@@ -99,7 +113,7 @@ class FileCrypt(object):
             self._set_password()
             keyring_password = keyring.get_password(app_name, username)
         while self.tries < 2:
-            attempted_password = getpass.getpass('Enter login password')
+            attempted_password = getpass.getpass('Enter login password\n-->')
             if keyring_password == pbkdf2.crypt(attempted_password,
                                                 keyring_password):
                 self.password = keyring_password
@@ -115,7 +129,7 @@ class FileCrypt(object):
         in keyring
         """
         while 1:
-            print 'Create a new password.\n\n'
+            print('Create a new folder password.\n\n')
             password1 = getpass.getpass('Enter password\n--> ')
             password2 = getpass.getpass('Enter password again\n--> ')
             if password1 == password2:
@@ -123,22 +137,13 @@ class FileCrypt(object):
             else:
                 msg = 'Passwords don\'t match.  Press enter to try again.'
                 raw_input(msg)
-        username = self.make_username()
-        app_name = 'NST-' + username
+        username, app_name = self.make_username_appname()
         hashed = pbkdf2.crypt(password1)
         keyring.set_password(app_name, username, hashed)
 
-    def _del_password(self):
-        username = self.make_username()
-        app_name = 'NST-' + username
-        self._get_password()
-        if self.password:
-            del self.self.password
-            keyring.delete_password(app_name, username)
-        else:
-            pass
-
-    def make_username(self):
+    def make_username_appname(self):
         """Makes username by base54 encoding current working directory.
         """
-        return base64.b64encode(_cwd)
+        username = base64.b64encode(bytes(_cwd))
+        app_name = 'NST-' + username
+        return username, app_name
