@@ -26,14 +26,18 @@ import logging
 import os
 import shutil
 
-from . import KeyHandlerError
-from .filecrypt import FileCrypt
-
 try:
     import rsa
 except ImportError:
-    raise KeyHandlerError('You must have rsa installed.',
-                          expected=True)
+    rsa = None
+
+from not_so_tuf.exceptions import KeyHandlerError
+from not_so_tuf.filecrypt import FileCrypt
+
+if rsa is None:
+    KeyHandlerError('You must have rsa installed.',
+                    expected=True)
+
 log = logging.getLogger(__name__)
 
 
@@ -56,24 +60,34 @@ class KeyHandler(object):
         """
         # Copies and sets all needed config attributes
         # for this object
-        self.app_dir = obj.config.get('APP_DIR')
         self.app_name = obj.config.get('APP_NAME')
         self.data_dir = obj.config.get('DEV_DATA_DIR')
         self.data_dir = os.path.join(self.data_dir, 'nst-data')
+
+        # Private key setup
         self.private_key_name = obj.config.get('PRIVATE_KEY_NAME')
         if self.private_key_name is None:
             self.private_key_name = self.app_name + '.pem'
+        if not self.private_key_name.endswith('.pem'):
+            self.private_key_name += '.pem'
+
+        # Public key setup
         self.public_key_name = obj.config.get('PUBLIC_KEY_NAME')
         if self.public_key_name is None:
             self.public_key_name = self.app_name + '.pub'
+        if not self.public_key_name.endswith('.pub'):
+            self.public_key_name += '.pub'
+
         self.key_length = obj.config.get('KEY_LENGTH', 2048)
+        if self.key_length is None:
+            self.key_length = 2048
         self.version_file = os.path.join(self.data_dir, 'version.json')
         self.keys_dir = os.path.join(self.data_dir, 'keys')
         if not os.path.exists(self.keys_dir):
             log.info('Creating keys directory')
             os.makedirs(self.keys_dir)
 
-    def make_keys(self, overwrite=False):
+    def make_keys(self, overwrite=False, test=False):
         """Makes public and private keys for signing and verification
 
         Kwargs:
@@ -89,9 +103,9 @@ class KeyHandler(object):
         # This is the public key you must distribute with your
         # program and pass to rsa_verify.
         self.pubkey = (pubkey.n, pubkey.e)
-        self._write_keys_to_file(overwrite)
+        self._write_keys_to_file(overwrite, test)
 
-    def _write_keys_to_file(self, overwrite):
+    def _write_keys_to_file(self, overwrite=False, test=False):
         """Writes keys to disk
 
         Args:
@@ -101,7 +115,7 @@ class KeyHandler(object):
         public = os.path.join(self.keys_dir, self.public_key_name)
         private = os.path.join(self.keys_dir, self.private_key_name)
         if os.path.exists(public) and os.path.exists(private):
-            if not overwrite:
+            if overwrite is False:
                 log.info('Cannot overwrite old key files.')
                 log.debug('Pass overwrite=True to make_keys to overwrite')
                 return
@@ -110,8 +124,9 @@ class KeyHandler(object):
         log.info('Writing keys to file')
         with open(private, 'w') as pri:
             pri.write(self.privkey)
-        fc = FileCrypt(private)
-        fc.encrypt()
+        if test is False:
+            fc = FileCrypt(private)
+            fc.encrypt()
         with open(public, 'w') as pub:
             pub.write(str(self.pubkey))
 
@@ -233,6 +248,7 @@ class KeyHandler(object):
 
     def copy_decrypted_private_key(self):
         privkey = os.path.join(self.keys_dir, self.private_key_name)
+        log.debug('Private Key Path: {}'.format(privkey))
         fc = FileCrypt(privkey)
         fc.decrypt()
         shutil.copy(privkey, privkey + ' copy')
@@ -240,8 +256,8 @@ class KeyHandler(object):
 
     def print_keys_to_console(self):
         """Prints public key and private key data to console"""
-        print 'Private Key:\n{}\n\n'.format(self.privkey)
-        print 'Public Key:\n{}\n\n'.format(self.pubkey)
+        print('Private Key:\n{}\n\n'.format(self.privkey))
+        print('Public Key:\n{}\n\n'.format(self.pubkey))
 
     def print_public_key(self):
         """Prints public key data to console"""
@@ -249,11 +265,11 @@ class KeyHandler(object):
         if os.path.exists(public):
             with open(public) as f:
                 key = f.read()
-            print 'Public Key:\n{}'.format(key)
+            print('Public Key:\n{}'.format(key))
         else:
-            print 'No Public Key Found'
+            print('No Public Key Found')
 
     def print_key_names_to_console(self):
         """Prints name of public and private key to console"""
-        print 'Private Key:\n{}\n\n'.format(self.private_key_name)
-        print 'Public Key:\n{}\n\n'.format(self.public_key_name)
+        print('Private Key:\n{}\n\n'.format(self.private_key_name))
+        print('Public Key:\n{}\n\n'.format(self.public_key_name))
