@@ -27,16 +27,17 @@ import os
 import re
 import shutil
 
-from . import PackageHandlerError
-from .utils import (ChDir, ask_yes_no, _get_package_hashes,
-                    _remove_hidden_stuff_mac, _version_string_to_tuple,
-                    _version_tuple_to_string)
-
 try:
     import bsdiff4
 except ImportError:
-    raise PackageHandlerError('You must have bsdiff4 installed.',
-                              expected=True)
+    bsdiff4 = None
+
+from not_so_tuf.exceptions import PackageHandlerError
+from not_so_tuf.utils import (ChDir, ask_yes_no, _get_package_hashes,
+                              _remove_hidden_stuff_mac,
+                              _version_string_to_tuple,
+                              _version_tuple_to_string)
+
 
 log = logging.getLogger(__name__)
 
@@ -364,6 +365,8 @@ class PackageHandler(object):
 
                 Tuple - (path to source file, patch number)
         """
+        if bsdiff4 is None:
+            return None
         src_file_path = None
         data_dir = os.path.join(self.files_dir, name)
         if os.path.exists(data_dir):
@@ -471,10 +474,10 @@ def _make_patch(patch_info):
         patch_number = patch_info['patch_num']
         src_path = patch_info['src']
         dst_path = patch_info['dst']
-        print "Patch name: {}".format(patch_name)
-        print 'Patch number: {}'.format(patch_number)
-        print 'Src: {}'.format(src_path)
-        print 'Dst: {}'.format(dst_path)
+        print("Patch name: {}".format(patch_name))
+        print('Patch number: {}'.format(patch_number))
+        print('Src: {}'.format(src_path))
+        print('Dst: {}'.format(dst_path))
 
         patch_name += '-' + str(patch_number)
         log.info('Creating patch')
