@@ -26,16 +26,17 @@ import logging
 import os
 import sys
 
-from .downloader import FileDownloader
-from .utils import (ChDir, _version_string_to_tuple,
-                    _version_tuple_to_string, platform_)
-
-from cStringIO import StringIO as BytesIO
 try:
     import bsdiff4
 except ImportError:
     bsdiff4 = None
 
+from not_so_tuf.compat import BytesIO
+from not_so_tuf.downloader import FileDownloader
+from not_so_tuf.utils import (ChDir, _version_string_to_tuple,
+                              _version_tuple_to_string, platform_)
+
+
 log = logging.getLogger(__name__)
 
 
