@@ -26,18 +26,23 @@ import os
 import sys
 import time
 
-from . import UploaderError
-from .utils import _remove_hidden_stuff_mac, ChDir
-
+# Really Ugly Imports
+# Suggestions welcome
 try:
-    from boto.exception import S3ResponseError
-    from boto.s3.connection import S3Connection
-    from boto.s3.key import Key
+    from boto3.s3.connection import S3Connection
 except ImportError:
-    boto = None
-
+    boto3 = None
+    try:
+        from boto.s3.connection import S3Connection
+        from boto.s3.key import Key
+    except ImportError:
+        boto = None
 from paramiko import SSHClient
-from scp import SCPClient
+
+from not_so_tuf.exceptions import UploaderError
+from not_so_tuf.scp import SCPClient
+from not_so_tuf.utils import _remove_hidden_stuff_mac, ChDir
+
 
 log = logging.getLogger(__name__)
 
@@ -200,7 +205,7 @@ class BaseUploader(object):
             msg = 'Uploading: {}' .format(f)
             msg2 = ' - File {} of {}\n'.format(self.files_completed,
                                                self.file_count)
-            print msg + msg2
+            print(msg + msg2)
             complete = self._upload_file(f)
             if complete:
                 log.debug('{} uploaded successfully'.format(f))
@@ -211,13 +216,13 @@ class BaseUploader(object):
         if len(self.failed_uploads) > 0:
             self._retry_upload()
         if len(self.failed_uploads) < 1:
-            print "\nUpload Complete"
+            print("\nUpload Complete")
             time.sleep(3)
         else:
-            print 'The following files were not uploaded'
+            print('The following files were not uploaded')
             for i in self.failed_uploads:
                 log.error('{} failed to upload'.format(i))
-                print i
+                print(i)
 
     def _retry_upload(self):
         """Takes list of failed downloads and try's to reupload them"""
@@ -229,7 +234,7 @@ class BaseUploader(object):
             msg = 'Retyring: {} - File {} of {}\n'.format(f,
                                                           count,
                                                           failed_count)
-            print msg
+            print(msg)
             complete = self._upload_file(f)
             if complete:
                 log.debug('{} uploaded on retry'.format(f))
@@ -237,12 +242,12 @@ class BaseUploader(object):
             else:
                 self.failed_uploads.append(f)
         if len(self.failed_uploads) > 0:
-            print '\nThe following files failed to upload...'
+            print('\nThe following files failed to upload...')
             for f in self.failed_uploads:
-                print f
+                print(f)
             time.sleep(3)
         else:
-            print '\nUpload complete'
+            print('\nUpload complete')
 
     def _connect(self):
         """Connects client attribute to service"""
@@ -341,14 +346,14 @@ class S3Uploader(BaseUploader):
             self.client.key = filename
             try:
                 self.client.set_contents_from_filename(filename,
-                                                   cb=s3_progress)
+                                                       cb=s3_progress)
                 self.client.make_public()
-                print 'Did that upload boy'
+                print('Did that upload boy')
                 return True
-            except S3ResponseError as e:
+            except Exception as e:
                 log.error(str(e), exc_info=True)
                 self._connect()
-                print 'Oopss didn\'t upload that boy'
+                print('Oopss didn\'t upload that boy')
                 return False
 
 
