@@ -27,10 +27,13 @@ import platform
 import struct
 import sys
 
+from not_so_tuf.compat import input_, print_function
 
 log = logging.getLogger(__name__)
 
-if getattr(sys, 'frozen', False):
+FROZEN = getattr(sys, 'frozen', False)
+
+if FROZEN:
     log.debug('Running frozen')
     # we are running in a |PyInstaller| bundle
     _cwd = os.path.dirname(sys.argv[0])
@@ -67,7 +70,7 @@ class ChDir(object):
         os.chdir(self.old_dir)
 
 
-def ask_yes_no(question, default='no'):
+def ask_yes_no(question, default='no', answer=None):
     """Will ask a question and keeps prompting until
     answered.
 
@@ -88,24 +91,29 @@ def ask_yes_no(question, default='no'):
     yes = ['yes', 'ye', 'y']
     no = ['no', 'n']
     if default in no:
-        help = '[N/y]?'
+        help_ = '[N/y]?'
         default = False
     else:
         default = True
-        help = '[Y/n]?'
+        help_ = '[Y/n]?'
     while 1:
-        display = question + '\n' + help
-        answer = raw_input(display)
+        display = question + '\n' + help_
+        if answer is None:
+            log.debug('Under None')
+            answer = raw_input(display)
         if answer == '':
+            log.debug('Under blank')
             return default
         if answer in yes:
+            log.debug('Must be true')
             return True
         elif answer in no:
+            log.debug('Must be false')
             return False
         else:
-            print 'Please answer yes or no only!\n'
-            raw_input('Press enter to continue')
-            print '\n\n\n\n'
+            print('Please answer yes or no only!\n')
+            input_('Press enter to continue')
+            print('\n\n\n\n')
 
 
 # Big Thanks to FiloSottile for making this lib for us
